( cd opt/kde/lib ; rm -rf liblancelot.so.0 )
( cd opt/kde/lib ; ln -sf liblancelot.so.1.7.0 liblancelot.so.0 )
( cd opt/kde/lib ; rm -rf librtm.so )
( cd opt/kde/lib ; ln -sf librtm.so.4 librtm.so )
( cd opt/kde/lib ; rm -rf libplasmapotdprovidercore.so.1 )
( cd opt/kde/lib ; ln -sf libplasmapotdprovidercore.so.1.0.0 libplasmapotdprovidercore.so.1 )
( cd opt/kde/lib ; rm -rf libplasmapotdprovidercore.so )
( cd opt/kde/lib ; ln -sf libplasmapotdprovidercore.so.1 libplasmapotdprovidercore.so )
( cd opt/kde/lib ; rm -rf liblancelot.so )
( cd opt/kde/lib ; ln -sf liblancelot.so.0 liblancelot.so )
( cd opt/kde/lib ; rm -rf libplasmaweather.so.4 )
( cd opt/kde/lib ; ln -sf libplasmaweather.so.4.4.0 libplasmaweather.so.4 )
( cd opt/kde/lib ; rm -rf libplasmacomicprovidercore.so )
( cd opt/kde/lib ; ln -sf libplasmacomicprovidercore.so.1 libplasmacomicprovidercore.so )
( cd opt/kde/lib ; rm -rf libplasmacomicprovidercore.so.1 )
( cd opt/kde/lib ; ln -sf libplasmacomicprovidercore.so.1.0.0 libplasmacomicprovidercore.so.1 )
( cd opt/kde/lib ; rm -rf librtm.so.4 )
( cd opt/kde/lib ; ln -sf librtm.so.4.4.0 librtm.so.4 )
( cd opt/kde/lib ; rm -rf libplasmaweather.so )
( cd opt/kde/lib ; ln -sf libplasmaweather.so.4 libplasmaweather.so )
#%% begin initialize kdeplasma_addon-4.4.5
if [ -f /opt/kde/bin/plamo_update_kde.sh ]; then
	/bin/bash /opt/kde/bin/plamo_update_kde.sh
fi
#%% end
